# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/nested_uint8_array_test_message.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg import uint8_array_test_message_pb2 as make87__messages__ros2_dot_jazzy_dot_rclpy__message__converter__msgs_dot_msg_dot_uint8__array__test__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\namake87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/nested_uint8_array_test_message.proto\x12;make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg\x1aZmake87_messages_ros2/jazzy/rclpy_message_converter_msgs/msg/uint8_array_test_message.proto\"\x81\x01\n\x1bNestedUint8ArrayTestMessage\x12\x62\n\x06\x61rrays\x18\x01 \x03(\x0b\x32R.make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg.Uint8ArrayTestMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rclpy_message_converter_msgs.msg.nested_uint8_array_test_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NESTEDUINT8ARRAYTESTMESSAGE']._serialized_start=255
  _globals['_NESTEDUINT8ARRAYTESTMESSAGE']._serialized_end=384
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/mounting_position_f.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/ibeo_msgs/msg/mounting_position_f.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\"\x8b\x01\n\x11MountingPositionF\x12\x11\n\tyaw_angle\x18\x01 \x01(\x02\x12\x13\n\x0bpitch_angle\x18\x02 \x01(\x02\x12\x12\n\nroll_angle\x18\x03 \x01(\x02\x12\x12\n\nx_position\x18\x04 \x01(\x02\x12\x12\n\ny_position\x18\x05 \x01(\x02\x12\x12\n\nz_position\x18\x06 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.mounting_position_f_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOUNTINGPOSITIONF']._serialized_start=113
  _globals['_MOUNTINGPOSITIONF']._serialized_end=252
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Node(_message.Message):
    __slots__ = ("id", "valid", "pose", "flags")
    ID_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    id: int
    valid: bool
    pose: _pose_pb2.Pose
    flags: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, id: _Optional[int] = ..., valid: bool = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., flags: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CostSource(_message.Message):
    __slots__ = ("cost_density", "aabb_min", "aabb_max")
    COST_DENSITY_FIELD_NUMBER: _ClassVar[int]
    AABB_MIN_FIELD_NUMBER: _ClassVar[int]
    AABB_MAX_FIELD_NUMBER: _ClassVar[int]
    cost_density: float
    aabb_min: _vector3_pb2.Vector3
    aabb_max: _vector3_pb2.Vector3
    def __init__(self, cost_density: _Optional[float] = ..., aabb_min: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., aabb_max: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/cfg_dgnss.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/ublox_msgs/msg/cfg_dgnss.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"1\n\x08\x43\x66gDGNSS\x12\x12\n\ndgnss_mode\x18\x01 \x01(\r\x12\x11\n\treserved0\x18\x02 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.cfg_dgnss_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGDGNSS']._serialized_start=108
  _globals['_CFGDGNSS']._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/fuse_msgs/srv/set_pose_deprecated.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__stamped__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/fuse_msgs/srv/set_pose_deprecated.proto\x12*make87_messages_ros2.rolling.fuse_msgs.srv\x1aQmake87_messages_ros2/rolling/geometry_msgs/msg/pose_with_covariance_stamped.proto\"s\n\x18SetPoseDeprecatedRequest\x12W\n\x04pose\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.rolling.geometry_msgs.msg.PoseWithCovarianceStamped\"\x1b\n\x19SetPoseDeprecatedResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.fuse_msgs.srv.set_pose_deprecated_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPOSEDEPRECATEDREQUEST']._serialized_start=199
  _globals['_SETPOSEDEPRECATEDREQUEST']._serialized_end=314
  _globals['_SETPOSEDEPRECATEDRESPONSE']._serialized_start=316
  _globals['_SETPOSEDEPRECATEDRESPONSE']._serialized_end=343
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationStatus(_message.Message):
    __slots__ = ("header", "conflict_version", "participants", "start_time", "last_response_time")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFLICT_VERSION_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_RESPONSE_TIME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    conflict_version: int
    participants: _containers.RepeatedScalarFieldContainer[int]
    start_time: _time_pb2.Time
    last_response_time: _time_pb2.Time
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., conflict_version: _Optional[int] = ..., participants: _Optional[_Iterable[int]] = ..., start_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., last_response_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VisibilityConstraint(_message.Message):
    __slots__ = ("target_radius", "target_pose", "cone_sides", "sensor_pose", "max_view_angle", "max_range_angle", "sensor_view_direction", "weight")
    TARGET_RADIUS_FIELD_NUMBER: _ClassVar[int]
    TARGET_POSE_FIELD_NUMBER: _ClassVar[int]
    CONE_SIDES_FIELD_NUMBER: _ClassVar[int]
    SENSOR_POSE_FIELD_NUMBER: _ClassVar[int]
    MAX_VIEW_ANGLE_FIELD_NUMBER: _ClassVar[int]
    MAX_RANGE_ANGLE_FIELD_NUMBER: _ClassVar[int]
    SENSOR_VIEW_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    target_radius: float
    target_pose: _pose_stamped_pb2.PoseStamped
    cone_sides: int
    sensor_pose: _pose_stamped_pb2.PoseStamped
    max_view_angle: float
    max_range_angle: float
    sensor_view_direction: int
    weight: float
    def __init__(self, target_radius: _Optional[float] = ..., target_pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., cone_sides: _Optional[int] = ..., sensor_pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., max_view_angle: _Optional[float] = ..., max_range_angle: _Optional[float] = ..., sensor_view_direction: _Optional[int] = ..., weight: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.plansys2_msgs.msg import action_pb2 as _action_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainActionDetailsRequest(_message.Message):
    __slots__ = ("action", "parameters")
    ACTION_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    action: str
    parameters: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, action: _Optional[str] = ..., parameters: _Optional[_Iterable[str]] = ...) -> None: ...

class GetDomainActionDetailsResponse(_message.Message):
    __slots__ = ("action", "success", "error_info")
    ACTION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    action: _action_pb2.Action
    success: bool
    error_info: str
    def __init__(self, action: _Optional[_Union[_action_pb2.Action, _Mapping]] = ..., success: bool = ..., error_info: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficDependency(_message.Message):
    __slots__ = ("header", "dependent_checkpoint", "on_participant", "on_plan", "on_route", "on_checkpoint")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DEPENDENT_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    ON_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    ON_PLAN_FIELD_NUMBER: _ClassVar[int]
    ON_ROUTE_FIELD_NUMBER: _ClassVar[int]
    ON_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    dependent_checkpoint: int
    on_participant: int
    on_plan: int
    on_route: int
    on_checkpoint: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., dependent_checkpoint: _Optional[int] = ..., on_participant: _Optional[int] = ..., on_plan: _Optional[int] = ..., on_route: _Optional[int] = ..., on_checkpoint: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NodesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class NodesResponse(_message.Message):
    __slots__ = ("nodes",)
    NODES_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, nodes: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as _occupancy_grid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectedMap(_message.Message):
    __slots__ = ("header", "map", "min_z", "max_z")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    MIN_Z_FIELD_NUMBER: _ClassVar[int]
    MAX_Z_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map: _occupancy_grid_pb2.OccupancyGrid
    min_z: float
    max_z: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map: _Optional[_Union[_occupancy_grid_pb2.OccupancyGrid, _Mapping]] = ..., min_z: _Optional[float] = ..., max_z: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import negotiation_participant_ack_pb2 as _negotiation_participant_ack_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NegotiationAck(_message.Message):
    __slots__ = ("conflict_version", "acknowledgments")
    CONFLICT_VERSION_FIELD_NUMBER: _ClassVar[int]
    ACKNOWLEDGMENTS_FIELD_NUMBER: _ClassVar[int]
    conflict_version: int
    acknowledgments: _containers.RepeatedCompositeFieldContainer[_negotiation_participant_ack_pb2.NegotiationParticipantAck]
    def __init__(self, conflict_version: _Optional[int] = ..., acknowledgments: _Optional[_Iterable[_Union[_negotiation_participant_ack_pb2.NegotiationParticipantAck, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/srv/set_analog_output.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.ur_msgs.msg import analog_pb2 as make87__messages__ros2_dot_jazzy_dot_ur__msgs_dot_msg_dot_analog__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/ur_msgs/srv/set_analog_output.proto\x12&make87_messages_ros2.jazzy.ur_msgs.srv\x1a\x33make87_messages_ros2/jazzy/ur_msgs/msg/analog.proto\"V\n\x16SetAnalogOutputRequest\x12<\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32..make87_messages_ros2.jazzy.ur_msgs.msg.Analog\"*\n\x17SetAnalogOutputResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.srv.set_analog_output_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_start=159
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_end=245
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_start=247
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_end=289
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"\x1b\n\x19HandEyeCalibrationRequest\"\xf8\x01\n\x1aHandEyeCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x42\n\x04pose\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\r\n\x05\x65rror\x18\x05 \x01(\x01\x12\x1f\n\x17translation_error_meter\x18\x06 \x01(\x01\x12\x1d\n\x15rotation_error_degree\x18\x07 \x01(\x01\x12\x15\n\rrobot_mounted\x18\x08 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.hand_eye_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDEYECALIBRATIONREQUEST']._serialized_start=186
  _globals['_HANDEYECALIBRATIONREQUEST']._serialized_end=213
  _globals['_HANDEYECALIBRATIONRESPONSE']._serialized_start=216
  _globals['_HANDEYECALIBRATIONRESPONSE']._serialized_end=464
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gprmc(_message.Message):
    __slots__ = ("header", "ros2_header", "message_id", "utc_seconds", "position_status", "lat", "lon", "lat_dir", "lon_dir", "speed", "track", "date", "mag_var", "mag_var_direction", "mode_indicator")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    UTC_SECONDS_FIELD_NUMBER: _ClassVar[int]
    POSITION_STATUS_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_DIR_FIELD_NUMBER: _ClassVar[int]
    LON_DIR_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    TRACK_FIELD_NUMBER: _ClassVar[int]
    DATE_FIELD_NUMBER: _ClassVar[int]
    MAG_VAR_FIELD_NUMBER: _ClassVar[int]
    MAG_VAR_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    MODE_INDICATOR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    message_id: str
    utc_seconds: float
    position_status: str
    lat: float
    lon: float
    lat_dir: str
    lon_dir: str
    speed: float
    track: float
    date: str
    mag_var: float
    mag_var_direction: str
    mode_indicator: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., utc_seconds: _Optional[float] = ..., position_status: _Optional[str] = ..., lat: _Optional[float] = ..., lon: _Optional[float] = ..., lat_dir: _Optional[str] = ..., lon_dir: _Optional[str] = ..., speed: _Optional[float] = ..., track: _Optional[float] = ..., date: _Optional[str] = ..., mag_var: _Optional[float] = ..., mag_var_direction: _Optional[str] = ..., mode_indicator: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as _robot_state_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import robot_trajectory_pb2 as _robot_trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DisplayTrajectory(_message.Message):
    __slots__ = ("model_id", "trajectory", "trajectory_start")
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_START_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    trajectory: _containers.RepeatedCompositeFieldContainer[_robot_trajectory_pb2.RobotTrajectory]
    trajectory_start: _robot_state_pb2.RobotState
    def __init__(self, model_id: _Optional[str] = ..., trajectory: _Optional[_Iterable[_Union[_robot_trajectory_pb2.RobotTrajectory, _Mapping]]] = ..., trajectory_start: _Optional[_Union[_robot_state_pb2.RobotState, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.marti_common_msgs.msg import service_header_pb2 as _service_header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestTopicServiceResponse(_message.Message):
    __slots__ = ("header", "srv_header", "response_value")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SRV_HEADER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_VALUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    srv_header: _service_header_pb2.ServiceHeader
    response_value: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., srv_header: _Optional[_Union[_service_header_pb2.ServiceHeader, _Mapping]] = ..., response_value: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDomainNameRequest(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _empty_pb2.Empty
    def __init__(self, request: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class GetDomainNameResponse(_message.Message):
    __slots__ = ("success", "name", "error_info")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    success: bool
    name: str
    error_info: str
    def __init__(self, success: bool = ..., name: _Optional[str] = ..., error_info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_reservation_msgs/msg/start_time_range.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/rmf_reservation_msgs/msg/start_time_range.proto\x12\x35make87_messages_ros2.rolling.rmf_reservation_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"\xfe\x01\n\x0eStartTimeRange\x12V\n\x13\x65\x61rliest_start_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x1f\n\x17has_earliest_start_time\x18\x02 \x01(\x08\x12T\n\x11latest_start_time\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x1d\n\x15has_latest_start_time\x18\x04 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_reservation_msgs.msg.start_time_range_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STARTTIMERANGE']._serialized_start=200
  _globals['_STARTTIMERANGE']._serialized_end=454
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceStatus(_message.Message):
    __slots__ = ("header", "ibeo_header", "scanner_type", "sensor_temperature", "frequency")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    SCANNER_TYPE_FIELD_NUMBER: _ClassVar[int]
    SENSOR_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    scanner_type: int
    sensor_temperature: float
    frequency: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., scanner_type: _Optional[int] = ..., sensor_temperature: _Optional[float] = ..., frequency: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetUTMZoneRequest(_message.Message):
    __slots__ = ("utm_zone",)
    UTM_ZONE_FIELD_NUMBER: _ClassVar[int]
    utm_zone: str
    def __init__(self, utm_zone: _Optional[str] = ...) -> None: ...

class SetUTMZoneResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpgga(_message.Message):
    __slots__ = ("header", "ros2_header", "message_id", "utc_seconds", "lat", "lon", "lat_dir", "lon_dir", "gps_qual", "num_sats", "hdop", "alt", "altitude_units", "undulation", "undulation_units", "diff_age", "station_id")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    UTC_SECONDS_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_DIR_FIELD_NUMBER: _ClassVar[int]
    LON_DIR_FIELD_NUMBER: _ClassVar[int]
    GPS_QUAL_FIELD_NUMBER: _ClassVar[int]
    NUM_SATS_FIELD_NUMBER: _ClassVar[int]
    HDOP_FIELD_NUMBER: _ClassVar[int]
    ALT_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_UNITS_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_UNITS_FIELD_NUMBER: _ClassVar[int]
    DIFF_AGE_FIELD_NUMBER: _ClassVar[int]
    STATION_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    message_id: str
    utc_seconds: float
    lat: float
    lon: float
    lat_dir: str
    lon_dir: str
    gps_qual: int
    num_sats: int
    hdop: float
    alt: float
    altitude_units: str
    undulation: float
    undulation_units: str
    diff_age: int
    station_id: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., utc_seconds: _Optional[float] = ..., lat: _Optional[float] = ..., lon: _Optional[float] = ..., lat_dir: _Optional[str] = ..., lon_dir: _Optional[str] = ..., gps_qual: _Optional[int] = ..., num_sats: _Optional[int] = ..., hdop: _Optional[float] = ..., alt: _Optional[float] = ..., altitude_units: _Optional[str] = ..., undulation: _Optional[float] = ..., undulation_units: _Optional[str] = ..., diff_age: _Optional[int] = ..., station_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/stereo_msgs/msg/disparity_image.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import region_of_interest_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_region__of__interest__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/stereo_msgs/msg/disparity_image.proto\x12+make87_messages_ros2.humble.stereo_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x37make87_messages_ros2/humble/sensor_msgs/msg/image.proto\x1a\x44make87_messages_ros2/humble/sensor_msgs/msg/region_of_interest.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xf2\x02\n\x0e\x44isparityImage\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x41\n\x05image\x18\x03 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Image\x12\t\n\x01\x66\x18\x04 \x01(\x02\x12\t\n\x01t\x18\x05 \x01(\x02\x12S\n\x0cvalid_window\x18\x06 \x01(\x0b\x32=.make87_messages_ros2.humble.sensor_msgs.msg.RegionOfInterest\x12\x15\n\rmin_disparity\x18\x07 \x01(\x02\x12\x15\n\rmax_disparity\x18\x08 \x01(\x02\x12\x0f\n\x07\x64\x65lta_d\x18\t \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.stereo_msgs.msg.disparity_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DISPARITYIMAGE']._serialized_start=332
  _globals['_DISPARITYIMAGE']._serialized_end=702
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Time(_message.Message):
    __slots__ = ("header", "clock_status", "offset", "offset_std", "utc_offset", "utc_year", "utc_month", "utc_day", "utc_hour", "utc_minute", "utc_millisecond", "utc_status")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CLOCK_STATUS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    OFFSET_STD_FIELD_NUMBER: _ClassVar[int]
    UTC_OFFSET_FIELD_NUMBER: _ClassVar[int]
    UTC_YEAR_FIELD_NUMBER: _ClassVar[int]
    UTC_MONTH_FIELD_NUMBER: _ClassVar[int]
    UTC_DAY_FIELD_NUMBER: _ClassVar[int]
    UTC_HOUR_FIELD_NUMBER: _ClassVar[int]
    UTC_MINUTE_FIELD_NUMBER: _ClassVar[int]
    UTC_MILLISECOND_FIELD_NUMBER: _ClassVar[int]
    UTC_STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    clock_status: str
    offset: float
    offset_std: float
    utc_offset: float
    utc_year: int
    utc_month: int
    utc_day: int
    utc_hour: int
    utc_minute: int
    utc_millisecond: int
    utc_status: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., clock_status: _Optional[str] = ..., offset: _Optional[float] = ..., offset_std: _Optional[float] = ..., utc_offset: _Optional[float] = ..., utc_year: _Optional[int] = ..., utc_month: _Optional[int] = ..., utc_day: _Optional[int] = ..., utc_hour: _Optional[int] = ..., utc_minute: _Optional[int] = ..., utc_millisecond: _Optional[int] = ..., utc_status: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CollisionMonitorState(_message.Message):
    __slots__ = ("action_type", "polygon_name")
    ACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    POLYGON_NAME_FIELD_NUMBER: _ClassVar[int]
    action_type: int
    polygon_name: str
    def __init__(self, action_type: _Optional[int] = ..., polygon_name: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_task_msgs.msg import dispatch_state_pb2 as _dispatch_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispatchStates(_message.Message):
    __slots__ = ("active", "finished")
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    FINISHED_FIELD_NUMBER: _ClassVar[int]
    active: _containers.RepeatedCompositeFieldContainer[_dispatch_state_pb2.DispatchState]
    finished: _containers.RepeatedCompositeFieldContainer[_dispatch_state_pb2.DispatchState]
    def __init__(self, active: _Optional[_Iterable[_Union[_dispatch_state_pb2.DispatchState, _Mapping]]] = ..., finished: _Optional[_Iterable[_Union[_dispatch_state_pb2.DispatchState, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/zbar_ros_interfaces/msg/symbol.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.vision_msgs.msg import point2_d_pb2 as make87__messages__ros2_dot_jazzy_dot_vision__msgs_dot_msg_dot_point2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/zbar_ros_interfaces/msg/symbol.proto\x12\x32make87_messages_ros2.jazzy.zbar_ros_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/vision_msgs/msg/point2_d.proto\"[\n\x06Symbol\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x43\n\x06points\x18\x02 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.vision_msgs.msg.Point2Db\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.zbar_ros_interfaces.msg.symbol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SYMBOL']._serialized_start=178
  _globals['_SYMBOL']._serialized_end=269
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.game_controller_spl_interfaces.msg import robot_info14_pb2 as _robot_info14_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TeamInfo14(_message.Message):
    __slots__ = ("team_number", "team_colour", "score", "penalty_shot", "single_shots", "message_budget", "players")
    TEAM_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TEAM_COLOUR_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    PENALTY_SHOT_FIELD_NUMBER: _ClassVar[int]
    SINGLE_SHOTS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_BUDGET_FIELD_NUMBER: _ClassVar[int]
    PLAYERS_FIELD_NUMBER: _ClassVar[int]
    team_number: int
    team_colour: int
    score: int
    penalty_shot: int
    single_shots: int
    message_budget: int
    players: _containers.RepeatedCompositeFieldContainer[_robot_info14_pb2.RobotInfo14]
    def __init__(self, team_number: _Optional[int] = ..., team_colour: _Optional[int] = ..., score: _Optional[int] = ..., penalty_shot: _Optional[int] = ..., single_shots: _Optional[int] = ..., message_budget: _Optional[int] = ..., players: _Optional[_Iterable[_Union[_robot_info14_pb2.RobotInfo14, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_query.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_query_participants_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__participants__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_query_spacetime_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_schedule__query__spacetime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_query.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aSmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_query_participants.proto\x1aPmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/schedule_query_spacetime.proto\"\xd1\x01\n\rScheduleQuery\x12\\\n\tspacetime\x18\x01 \x01(\x0b\x32I.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleQuerySpacetime\x12\x62\n\x0cparticipants\x18\x02 \x01(\x0b\x32L.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.ScheduleQueryParticipantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.schedule_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCHEDULEQUERY']._serialized_start=293
  _globals['_SCHEDULEQUERY']._serialized_end=502
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.test_interface_files.msg import arrays_pb2 as _arrays_pb2
from make87_messages_ros2.humble.test_interface_files.msg import bounded_sequences_pb2 as _bounded_sequences_pb2
from make87_messages_ros2.humble.test_interface_files.msg import unbounded_sequences_pb2 as _unbounded_sequences_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MultiNested(_message.Message):
    __slots__ = ("header", "array_of_arrays", "array_of_bounded_sequences", "array_of_unbounded_sequences", "bounded_sequence_of_arrays", "bounded_sequence_of_bounded_sequences", "bounded_sequence_of_unbounded_sequences", "unbounded_sequence_of_arrays", "unbounded_sequence_of_bounded_sequences", "unbounded_sequence_of_unbounded_sequences")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ARRAY_OF_ARRAYS_FIELD_NUMBER: _ClassVar[int]
    ARRAY_OF_BOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    ARRAY_OF_UNBOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_SEQUENCE_OF_ARRAYS_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_SEQUENCE_OF_BOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    BOUNDED_SEQUENCE_OF_UNBOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_SEQUENCE_OF_ARRAYS_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_SEQUENCE_OF_BOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    UNBOUNDED_SEQUENCE_OF_UNBOUNDED_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    array_of_arrays: _containers.RepeatedCompositeFieldContainer[_arrays_pb2.Arrays]
    array_of_bounded_sequences: _containers.RepeatedCompositeFieldContainer[_bounded_sequences_pb2.BoundedSequences]
    array_of_unbounded_sequences: _containers.RepeatedCompositeFieldContainer[_unbounded_sequences_pb2.UnboundedSequences]
    bounded_sequence_of_arrays: _containers.RepeatedCompositeFieldContainer[_arrays_pb2.Arrays]
    bounded_sequence_of_bounded_sequences: _containers.RepeatedCompositeFieldContainer[_bounded_sequences_pb2.BoundedSequences]
    bounded_sequence_of_unbounded_sequences: _containers.RepeatedCompositeFieldContainer[_unbounded_sequences_pb2.UnboundedSequences]
    unbounded_sequence_of_arrays: _containers.RepeatedCompositeFieldContainer[_arrays_pb2.Arrays]
    unbounded_sequence_of_bounded_sequences: _containers.RepeatedCompositeFieldContainer[_bounded_sequences_pb2.BoundedSequences]
    unbounded_sequence_of_unbounded_sequences: _containers.RepeatedCompositeFieldContainer[_unbounded_sequences_pb2.UnboundedSequences]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., array_of_arrays: _Optional[_Iterable[_Union[_arrays_pb2.Arrays, _Mapping]]] = ..., array_of_bounded_sequences: _Optional[_Iterable[_Union[_bounded_sequences_pb2.BoundedSequences, _Mapping]]] = ..., array_of_unbounded_sequences: _Optional[_Iterable[_Union[_unbounded_sequences_pb2.UnboundedSequences, _Mapping]]] = ..., bounded_sequence_of_arrays: _Optional[_Iterable[_Union[_arrays_pb2.Arrays, _Mapping]]] = ..., bounded_sequence_of_bounded_sequences: _Optional[_Iterable[_Union[_bounded_sequences_pb2.BoundedSequences, _Mapping]]] = ..., bounded_sequence_of_unbounded_sequences: _Optional[_Iterable[_Union[_unbounded_sequences_pb2.UnboundedSequences, _Mapping]]] = ..., unbounded_sequence_of_arrays: _Optional[_Iterable[_Union[_arrays_pb2.Arrays, _Mapping]]] = ..., unbounded_sequence_of_bounded_sequences: _Optional[_Iterable[_Union[_bounded_sequences_pb2.BoundedSequences, _Mapping]]] = ..., unbounded_sequence_of_unbounded_sequences: _Optional[_Iterable[_Union[_unbounded_sequences_pb2.UnboundedSequences, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_object_kinematics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_perception_msgs.msg import predicted_path_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__perception__msgs_dot_msg_dot_predicted__path__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_object_kinematics.proto\x12\x37make87_messages_ros2.jazzy.autoware_perception_msgs.msg\x1aLmake87_messages_ros2/jazzy/autoware_perception_msgs/msg/predicted_path.proto\x1aHmake87_messages_ros2/jazzy/geometry_msgs/msg/accel_with_covariance.proto\x1aGmake87_messages_ros2/jazzy/geometry_msgs/msg/pose_with_covariance.proto\x1aHmake87_messages_ros2/jazzy/geometry_msgs/msg/twist_with_covariance.proto\"\xbf\x03\n\x19PredictedObjectKinematics\x12\x66\n\x1cinitial_pose_with_covariance\x18\x01 \x01(\x0b\x32@.make87_messages_ros2.jazzy.geometry_msgs.msg.PoseWithCovariance\x12h\n\x1dinitial_twist_with_covariance\x18\x02 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.geometry_msgs.msg.TwistWithCovariance\x12o\n$initial_acceleration_with_covariance\x18\x03 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.geometry_msgs.msg.AccelWithCovariance\x12_\n\x0fpredicted_paths\x18\x04 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.autoware_perception_msgs.msg.PredictedPathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_perception_msgs.msg.predicted_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PREDICTEDOBJECTKINEMATICS']._serialized_start=450
  _globals['_PREDICTEDOBJECTKINEMATICS']._serialized_end=897
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmapTexture(_message.Message):
    __slots__ = ("cells", "width", "height", "resolution", "slice_pose")
    CELLS_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    SLICE_POSE_FIELD_NUMBER: _ClassVar[int]
    cells: _containers.RepeatedScalarFieldContainer[int]
    width: int
    height: int
    resolution: float
    slice_pose: _pose_pb2.Pose
    def __init__(self, cells: _Optional[_Iterable[int]] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., resolution: _Optional[float] = ..., slice_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as _twist_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EntityState(_message.Message):
    __slots__ = ("name", "pose", "twist", "reference_frame")
    NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    TWIST_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    pose: _pose_pb2.Pose
    twist: _twist_pb2.Twist
    reference_frame: str
    def __init__(self, name: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., twist: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ..., reference_frame: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/apply_planning_scene.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/moveit_msgs/srv/apply_planning_scene.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a?make87_messages_ros2/jazzy/moveit_msgs/msg/planning_scene.proto\"e\n\x19\x41pplyPlanningSceneRequest\x12H\n\x05scene\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.moveit_msgs.msg.PlanningScene\"-\n\x1a\x41pplyPlanningSceneResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.apply_planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_start=182
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_end=283
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_start=285
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_end=330
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FinishTrajectoryRequest(_message.Message):
    __slots__ = ("trajectory_id",)
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    trajectory_id: int
    def __init__(self, trajectory_id: _Optional[int] = ...) -> None: ...

class FinishTrajectoryResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _status_response_pb2.StatusResponse
    def __init__(self, status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/srv/unregister_participant.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rmf_traffic_msgs/srv/unregister_participant.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.srv\"6\n\x1cUnregisterParticipantRequest\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\x04\"D\n\x1dUnregisterParticipantResponse\x12\x14\n\x0c\x63onfirmation\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.srv.unregister_participant_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UNREGISTERPARTICIPANTREQUEST']._serialized_start=133
  _globals['_UNREGISTERPARTICIPANTREQUEST']._serialized_end=187
  _globals['_UNREGISTERPARTICIPANTRESPONSE']._serialized_start=189
  _globals['_UNREGISTERPARTICIPANTRESPONSE']._serialized_end=257
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Waypoint(_message.Message):
    __slots__ = ("frame", "command", "is_current", "autocontinue", "param1", "param2", "param3", "param4", "x_lat", "y_long", "z_alt")
    FRAME_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    IS_CURRENT_FIELD_NUMBER: _ClassVar[int]
    AUTOCONTINUE_FIELD_NUMBER: _ClassVar[int]
    PARAM1_FIELD_NUMBER: _ClassVar[int]
    PARAM2_FIELD_NUMBER: _ClassVar[int]
    PARAM3_FIELD_NUMBER: _ClassVar[int]
    PARAM4_FIELD_NUMBER: _ClassVar[int]
    X_LAT_FIELD_NUMBER: _ClassVar[int]
    Y_LONG_FIELD_NUMBER: _ClassVar[int]
    Z_ALT_FIELD_NUMBER: _ClassVar[int]
    frame: int
    command: int
    is_current: bool
    autocontinue: bool
    param1: float
    param2: float
    param3: float
    param4: float
    x_lat: float
    y_long: float
    z_alt: float
    def __init__(self, frame: _Optional[int] = ..., command: _Optional[int] = ..., is_current: bool = ..., autocontinue: bool = ..., param1: _Optional[float] = ..., param2: _Optional[float] = ..., param3: _Optional[float] = ..., param4: _Optional[float] = ..., x_lat: _Optional[float] = ..., y_long: _Optional[float] = ..., z_alt: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/grasp_planning.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/srv/grasp_planning.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/collision_object.proto\x1a\x38make87_messages_ros2/rolling/moveit_msgs/msg/grasp.proto\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/move_it_error_codes.proto\"\xbc\x02\n\x14GraspPlanningRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12M\n\x06target\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\x12\x18\n\x10support_surfaces\x18\x03 \x03(\t\x12M\n\x10\x63\x61ndidate_grasps\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Grasp\x12X\n\x11movable_obstacles\x18\x05 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\"\xb0\x01\n\x15GraspPlanningResponse\x12\x43\n\x06grasps\x18\x01 \x03(\x0b\x32\x33.make87_messages_ros2.rolling.moveit_msgs.msg.Grasp\x12R\n\nerror_code\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.rolling.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.grasp_planning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRASPPLANNINGREQUEST']._serialized_start=315
  _globals['_GRASPPLANNINGREQUEST']._serialized_end=631
  _globals['_GRASPPLANNINGRESPONSE']._serialized_start=634
  _globals['_GRASPPLANNINGRESPONSE']._serialized_end=810
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import meas_epoch_channel_type1_pb2 as _meas_epoch_channel_type1_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeasEpoch(_message.Message):
    __slots__ = ("header", "block_header", "n", "sb1_length", "sb2_length", "common_flags", "cum_clk_jumps", "type1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    N_FIELD_NUMBER: _ClassVar[int]
    SB1_LENGTH_FIELD_NUMBER: _ClassVar[int]
    SB2_LENGTH_FIELD_NUMBER: _ClassVar[int]
    COMMON_FLAGS_FIELD_NUMBER: _ClassVar[int]
    CUM_CLK_JUMPS_FIELD_NUMBER: _ClassVar[int]
    TYPE1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    n: int
    sb1_length: int
    sb2_length: int
    common_flags: int
    cum_clk_jumps: int
    type1: _containers.RepeatedCompositeFieldContainer[_meas_epoch_channel_type1_pb2.MeasEpochChannelType1]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., n: _Optional[int] = ..., sb1_length: _Optional[int] = ..., sb2_length: _Optional[int] = ..., common_flags: _Optional[int] = ..., cum_clk_jumps: _Optional[int] = ..., type1: _Optional[_Iterable[_Union[_meas_epoch_channel_type1_pb2.MeasEpochChannelType1, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SensorState(_message.Message):
    __slots__ = ("header", "ros2_header", "bumper", "cliff", "sonar", "illumination", "led", "button", "torque", "left_encoder", "right_encoder", "battery")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BUMPER_FIELD_NUMBER: _ClassVar[int]
    CLIFF_FIELD_NUMBER: _ClassVar[int]
    SONAR_FIELD_NUMBER: _ClassVar[int]
    ILLUMINATION_FIELD_NUMBER: _ClassVar[int]
    LED_FIELD_NUMBER: _ClassVar[int]
    BUTTON_FIELD_NUMBER: _ClassVar[int]
    TORQUE_FIELD_NUMBER: _ClassVar[int]
    LEFT_ENCODER_FIELD_NUMBER: _ClassVar[int]
    RIGHT_ENCODER_FIELD_NUMBER: _ClassVar[int]
    BATTERY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    bumper: int
    cliff: float
    sonar: float
    illumination: float
    led: int
    button: int
    torque: bool
    left_encoder: int
    right_encoder: int
    battery: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., bumper: _Optional[int] = ..., cliff: _Optional[float] = ..., sonar: _Optional[float] = ..., illumination: _Optional[float] = ..., led: _Optional[int] = ..., button: _Optional[int] = ..., torque: bool = ..., left_encoder: _Optional[int] = ..., right_encoder: _Optional[int] = ..., battery: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.geographic_msgs.msg import bounding_box_pb2 as _bounding_box_pb2
from make87_messages_ros2.jazzy.geographic_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.jazzy.geographic_msgs.msg import route_segment_pb2 as _route_segment_pb2
from make87_messages_ros2.jazzy.geographic_msgs.msg import way_point_pb2 as _way_point_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RouteNetwork(_message.Message):
    __slots__ = ("header", "id", "bounds", "points", "segments", "props")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    BOUNDS_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    PROPS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: _uuid_pb2.UUID
    bounds: _bounding_box_pb2.BoundingBox
    points: _containers.RepeatedCompositeFieldContainer[_way_point_pb2.WayPoint]
    segments: _containers.RepeatedCompositeFieldContainer[_route_segment_pb2.RouteSegment]
    props: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., bounds: _Optional[_Union[_bounding_box_pb2.BoundingBox, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_way_point_pb2.WayPoint, _Mapping]]] = ..., segments: _Optional[_Iterable[_Union[_route_segment_pb2.RouteSegment, _Mapping]]] = ..., props: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import motion_plan_request_pb2 as _motion_plan_request_pb2
from make87_messages_ros2.humble.moveit_msgs.msg import motion_plan_response_pb2 as _motion_plan_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMotionPlanRequest(_message.Message):
    __slots__ = ("header", "motion_plan_request")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MOTION_PLAN_REQUEST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    motion_plan_request: _motion_plan_request_pb2.MotionPlanRequest
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., motion_plan_request: _Optional[_Union[_motion_plan_request_pb2.MotionPlanRequest, _Mapping]] = ...) -> None: ...

class GetMotionPlanResponse(_message.Message):
    __slots__ = ("header", "motion_plan_response")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MOTION_PLAN_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    motion_plan_response: _motion_plan_response_pb2.MotionPlanResponse
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., motion_plan_response: _Optional[_Union[_motion_plan_response_pb2.MotionPlanResponse, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Color(_message.Message):
    __slots__ = ("r", "g", "b")
    R_FIELD_NUMBER: _ClassVar[int]
    G_FIELD_NUMBER: _ClassVar[int]
    B_FIELD_NUMBER: _ClassVar[int]
    r: int
    g: int
    b: int
    def __init__(self, r: _Optional[int] = ..., g: _Optional[int] = ..., b: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.rc_common_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraParam(_message.Message):
    __slots__ = ("header", "is_color_camera", "exposure_time", "gain", "line_status_all", "line_source", "extra_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IS_COLOR_CAMERA_FIELD_NUMBER: _ClassVar[int]
    EXPOSURE_TIME_FIELD_NUMBER: _ClassVar[int]
    GAIN_FIELD_NUMBER: _ClassVar[int]
    LINE_STATUS_ALL_FIELD_NUMBER: _ClassVar[int]
    LINE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    is_color_camera: bool
    exposure_time: float
    gain: float
    line_status_all: int
    line_source: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    extra_data: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., is_color_camera: bool = ..., exposure_time: _Optional[float] = ..., gain: _Optional[float] = ..., line_status_all: _Optional[int] = ..., line_source: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ..., extra_data: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/msg/range_rectangle.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rc_reason_msgs/msg/range_rectangle.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.msg\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/rectangle.proto\"\xb8\x01\n\x0eRangeRectangle\x12R\n\x0emin_dimensions\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12R\n\x0emax_dimensions\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.msg.range_rectangle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RANGERECTANGLE']._serialized_start=188
  _globals['_RANGERECTANGLE']._serialized_end=372
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import point32_pb2 as _point32_pb2
from make87_messages_ros2.rolling.sensor_msgs.msg import channel_float32_pb2 as _channel_float32_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointCloud(_message.Message):
    __slots__ = ("header", "points", "channels")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    points: _containers.RepeatedCompositeFieldContainer[_point32_pb2.Point32]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_float32_pb2.ChannelFloat32]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_point32_pb2.Point32, _Mapping]]] = ..., channels: _Optional[_Iterable[_Union[_channel_float32_pb2.ChannelFloat32, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/msg/camera_model.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_camera__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/humble/rtabmap_msgs/msg/camera_model.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/geometry_msgs/msg/transform.proto\x1a=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\"\xdc\x01\n\x0b\x43\x61meraModel\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12L\n\x0b\x63\x61mera_info\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.sensor_msgs.msg.CameraInfo\x12Q\n\x0flocal_transform\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.humble.geometry_msgs.msg.Transformb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.msg.camera_model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERAMODEL']._serialized_start=275
  _globals['_CAMERAMODEL']._serialized_end=495
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetCostRequest(_message.Message):
    __slots__ = ("use_footprint", "x", "y", "theta")
    USE_FOOTPRINT_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    THETA_FIELD_NUMBER: _ClassVar[int]
    use_footprint: bool
    x: float
    y: float
    theta: float
    def __init__(self, use_footprint: bool = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., theta: _Optional[float] = ...) -> None: ...

class GetCostResponse(_message.Message):
    __slots__ = ("cost",)
    COST_FIELD_NUMBER: _ClassVar[int]
    cost: float
    def __init__(self, cost: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigLoggerRequest(_message.Message):
    __slots__ = ("logger_name", "level")
    LOGGER_NAME_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    logger_name: str
    level: str
    def __init__(self, logger_name: _Optional[str] = ..., level: _Optional[str] = ...) -> None: ...

class ConfigLoggerResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/plansys2_msgs/srv/get_problem_instance_details.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.plansys2_msgs.msg import param_pb2 as make87__messages__ros2_dot_jazzy_dot_plansys2__msgs_dot_msg_dot_param__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/plansys2_msgs/srv/get_problem_instance_details.proto\x12,make87_messages_ros2.jazzy.plansys2_msgs.srv\x1a\x38make87_messages_ros2/jazzy/plansys2_msgs/msg/param.proto\"4\n GetProblemInstanceDetailsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\x8f\x01\n!GetProblemInstanceDetailsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x45\n\x08instance\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.plansys2_msgs.msg.Param\x12\x12\n\nerror_info\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.plansys2_msgs.srv.get_problem_instance_details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPROBLEMINSTANCEDETAILSREQUEST']._serialized_start=187
  _globals['_GETPROBLEMINSTANCEDETAILSREQUEST']._serialized_end=239
  _globals['_GETPROBLEMINSTANCEDETAILSRESPONSE']._serialized_start=242
  _globals['_GETPROBLEMINSTANCEDETAILSRESPONSE']._serialized_end=385
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConfigureOutputsKdFreqDeadbandCmd(_message.Message):
    __slots__ = ("header", "confirm", "kd", "closed_loop_freq", "error_dead_band")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_FIELD_NUMBER: _ClassVar[int]
    KD_FIELD_NUMBER: _ClassVar[int]
    CLOSED_LOOP_FREQ_FIELD_NUMBER: _ClassVar[int]
    ERROR_DEAD_BAND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    confirm: bool
    kd: int
    closed_loop_freq: int
    error_dead_band: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., confirm: bool = ..., kd: _Optional[int] = ..., closed_loop_freq: _Optional[int] = ..., error_dead_band: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalDeviceInformation(_message.Message):
    __slots__ = ("header", "vendor_name", "model_name", "custom_name", "firmware_version", "hardware_version", "uid", "cap_flags", "custom_cap_flags", "roll_min", "roll_max", "pitch_min", "pitch_max", "yaw_min", "yaw_max")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VENDOR_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_NAME_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    CAP_FLAGS_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CAP_FLAGS_FIELD_NUMBER: _ClassVar[int]
    ROLL_MIN_FIELD_NUMBER: _ClassVar[int]
    ROLL_MAX_FIELD_NUMBER: _ClassVar[int]
    PITCH_MIN_FIELD_NUMBER: _ClassVar[int]
    PITCH_MAX_FIELD_NUMBER: _ClassVar[int]
    YAW_MIN_FIELD_NUMBER: _ClassVar[int]
    YAW_MAX_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    vendor_name: str
    model_name: str
    custom_name: str
    firmware_version: int
    hardware_version: int
    uid: int
    cap_flags: int
    custom_cap_flags: int
    roll_min: float
    roll_max: float
    pitch_min: float
    pitch_max: float
    yaw_min: float
    yaw_max: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., vendor_name: _Optional[str] = ..., model_name: _Optional[str] = ..., custom_name: _Optional[str] = ..., firmware_version: _Optional[int] = ..., hardware_version: _Optional[int] = ..., uid: _Optional[int] = ..., cap_flags: _Optional[int] = ..., custom_cap_flags: _Optional[int] = ..., roll_min: _Optional[float] = ..., roll_max: _Optional[float] = ..., pitch_min: _Optional[float] = ..., pitch_max: _Optional[float] = ..., yaw_min: _Optional[float] = ..., yaw_max: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric_family.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import metric_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_metric__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric_family.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.msg\x1a\x41make87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric.proto\"\x80\x01\n\x0cMetricFamily\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12M\n\x07metrics\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.Metricb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.metric_family_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METRICFAMILY']._serialized_start=198
  _globals['_METRICFAMILY']._serialized_end=326
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TF2Error(_message.Message):
    __slots__ = ("error", "error_string")
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_STRING_FIELD_NUMBER: _ClassVar[int]
    error: int
    error_string: str
    def __init__(self, error: _Optional[int] = ..., error_string: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnsToCmdConnect(_message.Message):
    __slots__ = ("header", "command", "cmd_connect_ans_d7", "cmd_connect_ans_d6", "cmd_connect_ans_d5", "cmd_connect_ans_d4", "cmd_connect_ans_d3", "cmd_connect_ans_d2", "cmd_connect_ans_d1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D7_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D6_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D5_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D4_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D3_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D2_FIELD_NUMBER: _ClassVar[int]
    CMD_CONNECT_ANS_D1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    command: int
    cmd_connect_ans_d7: int
    cmd_connect_ans_d6: int
    cmd_connect_ans_d5: int
    cmd_connect_ans_d4: int
    cmd_connect_ans_d3: int
    cmd_connect_ans_d2: int
    cmd_connect_ans_d1: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., command: _Optional[int] = ..., cmd_connect_ans_d7: _Optional[int] = ..., cmd_connect_ans_d6: _Optional[int] = ..., cmd_connect_ans_d5: _Optional[int] = ..., cmd_connect_ans_d4: _Optional[int] = ..., cmd_connect_ans_d3: _Optional[int] = ..., cmd_connect_ans_d2: _Optional[int] = ..., cmd_connect_ans_d1: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TypeDef(_message.Message):
    __slots__ = ("type", "fieldnames", "fieldtypes", "fieldarraylen", "examples", "constnames", "constvalues")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FIELDNAMES_FIELD_NUMBER: _ClassVar[int]
    FIELDTYPES_FIELD_NUMBER: _ClassVar[int]
    FIELDARRAYLEN_FIELD_NUMBER: _ClassVar[int]
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    CONSTNAMES_FIELD_NUMBER: _ClassVar[int]
    CONSTVALUES_FIELD_NUMBER: _ClassVar[int]
    type: str
    fieldnames: _containers.RepeatedScalarFieldContainer[str]
    fieldtypes: _containers.RepeatedScalarFieldContainer[str]
    fieldarraylen: _containers.RepeatedScalarFieldContainer[int]
    examples: _containers.RepeatedScalarFieldContainer[str]
    constnames: _containers.RepeatedScalarFieldContainer[str]
    constvalues: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, type: _Optional[str] = ..., fieldnames: _Optional[_Iterable[str]] = ..., fieldtypes: _Optional[_Iterable[str]] = ..., fieldarraylen: _Optional[_Iterable[int]] = ..., examples: _Optional[_Iterable[str]] = ..., constnames: _Optional[_Iterable[str]] = ..., constvalues: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FriConfiguration(_message.Message):
    __slots__ = ("header", "receive_multiplier", "send_period_ms")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RECEIVE_MULTIPLIER_FIELD_NUMBER: _ClassVar[int]
    SEND_PERIOD_MS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    receive_multiplier: int
    send_period_ms: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., receive_multiplier: _Optional[int] = ..., send_period_ms: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_fleet_msgs.msg import location_pb2 as _location_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DockParameter(_message.Message):
    __slots__ = ("start", "finish", "path")
    START_FIELD_NUMBER: _ClassVar[int]
    FINISH_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    start: str
    finish: str
    path: _containers.RepeatedCompositeFieldContainer[_location_pb2.Location]
    def __init__(self, start: _Optional[str] = ..., finish: _Optional[str] = ..., path: _Optional[_Iterable[_Union[_location_pb2.Location, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_outputs.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_outputs.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\"\x9f\x07\n\x12\x41pplicationOutputs\x12(\n evaluation_path_outputs_eval_out\x18\x01 \x03(\x08\x12\'\n\x1f\x65valuation_path_outputs_is_safe\x18\x02 \x03(\x08\x12(\n evaluation_path_outputs_is_valid\x18\x03 \x03(\x08\x12&\n\x1emonitoring_case_number_outputs\x18\x04 \x03(\r\x12,\n$monitoring_case_number_outputs_flags\x18\x05 \x03(\x08\x12\x19\n\x11sleep_mode_output\x18\x06 \x01(\r\x12\x1f\n\x17sleep_mode_output_valid\x18\x07 \x01(\x08\x12(\n error_flag_contamination_warning\x18\x08 \x01(\x08\x12&\n\x1e\x65rror_flag_contamination_error\x18\t \x01(\x08\x12%\n\x1d\x65rror_flag_manipulation_error\x18\n \x01(\x08\x12\x18\n\x10\x65rror_flag_glare\x18\x0b \x01(\x08\x12-\n%error_flag_reference_contour_intruded\x18\x0c \x01(\x08\x12!\n\x19\x65rror_flag_critical_error\x18\r \x01(\x08\x12\x1d\n\x15\x65rror_flags_are_valid\x18\x0e \x01(\x08\x12*\n\"linear_velocity_outputs_velocity_0\x18\x0f \x01(\x05\x12\x30\n(linear_velocity_outputs_velocity_0_valid\x18\x10 \x01(\x08\x12=\n5linear_velocity_outputs_velocity_0_transmitted_safely\x18\x11 \x01(\x08\x12*\n\"linear_velocity_outputs_velocity_1\x18\x12 \x01(\x05\x12\x30\n(linear_velocity_outputs_velocity_1_valid\x18\x13 \x01(\x08\x12=\n5linear_velocity_outputs_velocity_1_transmitted_safely\x18\x14 \x01(\x08\x12\x1a\n\x12resulting_velocity\x18\x15 \x03(\x05\x12 \n\x18resulting_velocity_flags\x18\x16 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.application_outputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APPLICATIONOUTPUTS']._serialized_start=157
  _globals['_APPLICATIONOUTPUTS']._serialized_end=1084
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ItineraryClear(_message.Message):
    __slots__ = ("participant", "itinerary_version")
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    ITINERARY_VERSION_FIELD_NUMBER: _ClassVar[int]
    participant: int
    itinerary_version: int
    def __init__(self, participant: _Optional[int] = ..., itinerary_version: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SysStatus(_message.Message):
    __slots__ = ("header", "sensors_present", "sensors_enabled", "sensors_health", "load", "voltage_battery", "current_battery", "battery_remaining", "drop_rate_comm", "errors_comm", "errors_count1", "errors_count2", "errors_count3", "errors_count4")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SENSORS_PRESENT_FIELD_NUMBER: _ClassVar[int]
    SENSORS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    SENSORS_HEALTH_FIELD_NUMBER: _ClassVar[int]
    LOAD_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_BATTERY_FIELD_NUMBER: _ClassVar[int]
    CURRENT_BATTERY_FIELD_NUMBER: _ClassVar[int]
    BATTERY_REMAINING_FIELD_NUMBER: _ClassVar[int]
    DROP_RATE_COMM_FIELD_NUMBER: _ClassVar[int]
    ERRORS_COMM_FIELD_NUMBER: _ClassVar[int]
    ERRORS_COUNT1_FIELD_NUMBER: _ClassVar[int]
    ERRORS_COUNT2_FIELD_NUMBER: _ClassVar[int]
    ERRORS_COUNT3_FIELD_NUMBER: _ClassVar[int]
    ERRORS_COUNT4_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sensors_present: int
    sensors_enabled: int
    sensors_health: int
    load: int
    voltage_battery: int
    current_battery: int
    battery_remaining: int
    drop_rate_comm: int
    errors_comm: int
    errors_count1: int
    errors_count2: int
    errors_count3: int
    errors_count4: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sensors_present: _Optional[int] = ..., sensors_enabled: _Optional[int] = ..., sensors_health: _Optional[int] = ..., load: _Optional[int] = ..., voltage_battery: _Optional[int] = ..., current_battery: _Optional[int] = ..., battery_remaining: _Optional[int] = ..., drop_rate_comm: _Optional[int] = ..., errors_comm: _Optional[int] = ..., errors_count1: _Optional[int] = ..., errors_count2: _Optional[int] = ..., errors_count3: _Optional[int] = ..., errors_count4: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as _twist_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as _wrench_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MultiDOFJointState(_message.Message):
    __slots__ = ("header", "joint_names", "transforms", "twist", "wrench")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_NAMES_FIELD_NUMBER: _ClassVar[int]
    TRANSFORMS_FIELD_NUMBER: _ClassVar[int]
    TWIST_FIELD_NUMBER: _ClassVar[int]
    WRENCH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_names: _containers.RepeatedScalarFieldContainer[str]
    transforms: _containers.RepeatedCompositeFieldContainer[_transform_pb2.Transform]
    twist: _containers.RepeatedCompositeFieldContainer[_twist_pb2.Twist]
    wrench: _containers.RepeatedCompositeFieldContainer[_wrench_pb2.Wrench]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_names: _Optional[_Iterable[str]] = ..., transforms: _Optional[_Iterable[_Union[_transform_pb2.Transform, _Mapping]]] = ..., twist: _Optional[_Iterable[_Union[_twist_pb2.Twist, _Mapping]]] = ..., wrench: _Optional[_Iterable[_Union[_wrench_pb2.Wrench, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rmf_scheduler_msgs.msg import payload_pb2 as _payload_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Schedule(_message.Message):
    __slots__ = ("header", "name", "created_at", "schedule", "start_at", "finish_at", "group", "payload")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    START_AT_FIELD_NUMBER: _ClassVar[int]
    FINISH_AT_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    created_at: int
    schedule: str
    start_at: int
    finish_at: int
    group: str
    payload: _payload_pb2.Payload
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., created_at: _Optional[int] = ..., schedule: _Optional[str] = ..., start_at: _Optional[int] = ..., finish_at: _Optional[int] = ..., group: _Optional[str] = ..., payload: _Optional[_Union[_payload_pb2.Payload, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Touch(_message.Message):
    __slots__ = ("head_front", "head_middle", "head_rear")
    HEAD_FRONT_FIELD_NUMBER: _ClassVar[int]
    HEAD_MIDDLE_FIELD_NUMBER: _ClassVar[int]
    HEAD_REAR_FIELD_NUMBER: _ClassVar[int]
    head_front: bool
    head_middle: bool
    head_rear: bool
    def __init__(self, head_front: bool = ..., head_middle: bool = ..., head_rear: bool = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RouteSegment(_message.Message):
    __slots__ = ("id", "type", "orientation", "motion_type", "start", "end", "center", "level")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    MOTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    CENTER_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    id: int
    type: int
    orientation: int
    motion_type: int
    start: _pose_pb2.Pose
    end: _pose_pb2.Pose
    center: _pose_pb2.Pose
    level: int
    def __init__(self, id: _Optional[int] = ..., type: _Optional[int] = ..., orientation: _Optional[int] = ..., motion_type: _Optional[int] = ..., start: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., end: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., center: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., level: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BurstRequest(_message.Message):
    __slots__ = ("num_messages",)
    NUM_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    num_messages: int
    def __init__(self, num_messages: _Optional[int] = ...) -> None: ...

class BurstResponse(_message.Message):
    __slots__ = ("actually_burst",)
    ACTUALLY_BURST_FIELD_NUMBER: _ClassVar[int]
    actually_burst: int
    def __init__(self, actually_burst: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/device_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import active_monitoring_case_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safevisionary__interfaces_dot_msg_dot_active__monitoring__case__pb2
from make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg import general_status_pb2 as make87__messages__ros2_dot_rolling_dot_sick__safevisionary__interfaces_dot_msg_dot_general__status__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/device_status.proto\x12>make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg\x1a[make87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/active_monitoring_case.proto\x1aSmake87_messages_ros2/rolling/sick_safevisionary_interfaces/msg/general_status.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xb3\x03\n\x0c\x44\x65viceStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x65\n\x0egeneral_status\x18\x03 \x01(\x0b\x32M.make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.GeneralStatus\x12\x1a\n\x12\x63op_safety_related\x18\x04 \x01(\r\x12\x1e\n\x16\x63op_non_safety_related\x18\x05 \x01(\r\x12\x1a\n\x12\x63op_reset_required\x18\x06 \x01(\r\x12t\n\x16\x61\x63tive_monitoring_case\x18\x07 \x01(\x0b\x32T.make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.ActiveMonitoringCase\x12\x1b\n\x13\x63ontamination_level\x18\x08 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.sick_safevisionary_interfaces.msg.device_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEVICESTATUS']._serialized_start=385
  _globals['_DEVICESTATUS']._serialized_end=820
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/webots_ros2_msgs/srv/spawn_node_from_string.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/jazzy/webots_ros2_msgs/srv/spawn_node_from_string.proto\x12/make87_messages_ros2.jazzy.webots_ros2_msgs.srv\"*\n\x1aSpawnNodeFromStringRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\".\n\x1bSpawnNodeFromStringResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.webots_ros2_msgs.srv.spawn_node_from_string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SPAWNNODEFROMSTRINGREQUEST']._serialized_start=129
  _globals['_SPAWNNODEFROMSTRINGREQUEST']._serialized_end=171
  _globals['_SPAWNNODEFROMSTRINGRESPONSE']._serialized_start=173
  _globals['_SPAWNNODEFROMSTRINGRESPONSE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SynthesisRequest(_message.Message):
    __slots__ = ("header", "name", "system", "goal", "initial_condition", "sm_outcomes")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_FIELD_NUMBER: _ClassVar[int]
    GOAL_FIELD_NUMBER: _ClassVar[int]
    INITIAL_CONDITION_FIELD_NUMBER: _ClassVar[int]
    SM_OUTCOMES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    system: str
    goal: str
    initial_condition: str
    sm_outcomes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., system: _Optional[str] = ..., goal: _Optional[str] = ..., initial_condition: _Optional[str] = ..., sm_outcomes: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.rolling.grasping_msgs.msg import object_pb2 as _object_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import grasp_pb2 as _grasp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GraspableObject(_message.Message):
    __slots__ = ("object", "grasps")
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    GRASPS_FIELD_NUMBER: _ClassVar[int]
    object: _object_pb2.Object
    grasps: _containers.RepeatedCompositeFieldContainer[_grasp_pb2.Grasp]
    def __init__(self, object: _Optional[_Union[_object_pb2.Object, _Mapping]] = ..., grasps: _Optional[_Iterable[_Union[_grasp_pb2.Grasp, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CostmapFilterInfo(_message.Message):
    __slots__ = ("header", "type", "filter_mask_topic", "base", "multiplier")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FILTER_MASK_TOPIC_FIELD_NUMBER: _ClassVar[int]
    BASE_FIELD_NUMBER: _ClassVar[int]
    MULTIPLIER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    type: int
    filter_mask_topic: str
    base: float
    multiplier: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., type: _Optional[int] = ..., filter_mask_topic: _Optional[str] = ..., base: _Optional[float] = ..., multiplier: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/test_interface_files/msg/nested.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.test_interface_files.msg import basic_types_pb2 as make87__messages__ros2_dot_rolling_dot_test__interface__files_dot_msg_dot_basic__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/test_interface_files/msg/nested.proto\x12\x35make87_messages_ros2.rolling.test_interface_files.msg\x1aGmake87_messages_ros2/rolling/test_interface_files/msg/basic_types.proto\"f\n\x06Nested\x12\\\n\x11\x62\x61sic_types_value\x18\x01 \x01(\x0b\x32\x41.make87_messages_ros2.rolling.test_interface_files.msg.BasicTypesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.test_interface_files.msg.nested_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NESTED']._serialized_start=198
  _globals['_NESTED']._serialized_end=300
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Pose(_message.Message):
    __slots__ = ("position", "orientation")
    POSITION_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    position: _point_pb2.Point
    orientation: _quaternion_pb2.Quaternion
    def __init__(self, position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FrameGraphRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FrameGraphResponse(_message.Message):
    __slots__ = ("frame_yaml",)
    FRAME_YAML_FIELD_NUMBER: _ClassVar[int]
    frame_yaml: str
    def __init__(self, frame_yaml: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AidEPH(_message.Message):
    __slots__ = ("svid", "how", "sf1d", "sf2d", "sf3d")
    SVID_FIELD_NUMBER: _ClassVar[int]
    HOW_FIELD_NUMBER: _ClassVar[int]
    SF1D_FIELD_NUMBER: _ClassVar[int]
    SF2D_FIELD_NUMBER: _ClassVar[int]
    SF3D_FIELD_NUMBER: _ClassVar[int]
    svid: int
    how: int
    sf1d: _containers.RepeatedScalarFieldContainer[int]
    sf2d: _containers.RepeatedScalarFieldContainer[int]
    sf3d: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, svid: _Optional[int] = ..., how: _Optional[int] = ..., sf1d: _Optional[_Iterable[int]] = ..., sf2d: _Optional[_Iterable[int]] = ..., sf3d: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Transform(_message.Message):
    __slots__ = ("header", "translation", "rotation")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    ROTATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    translation: _vector3_pb2.Vector3
    rotation: _quaternion_pb2.Quaternion
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., translation: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., rotation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import measx_data_pb2 as _measx_data_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXRxmMeasx(_message.Message):
    __slots__ = ("header", "version", "gps_tow", "glo_tow", "bds_tow", "qzss_tow", "gps_tow_acc", "glo_tow_acc", "bds_tow_acc", "qzss_tow_acc", "num_sv", "flags", "sv_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    GPS_TOW_FIELD_NUMBER: _ClassVar[int]
    GLO_TOW_FIELD_NUMBER: _ClassVar[int]
    BDS_TOW_FIELD_NUMBER: _ClassVar[int]
    QZSS_TOW_FIELD_NUMBER: _ClassVar[int]
    GPS_TOW_ACC_FIELD_NUMBER: _ClassVar[int]
    GLO_TOW_ACC_FIELD_NUMBER: _ClassVar[int]
    BDS_TOW_ACC_FIELD_NUMBER: _ClassVar[int]
    QZSS_TOW_ACC_FIELD_NUMBER: _ClassVar[int]
    NUM_SV_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    SV_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    gps_tow: int
    glo_tow: int
    bds_tow: int
    qzss_tow: int
    gps_tow_acc: int
    glo_tow_acc: int
    bds_tow_acc: int
    qzss_tow_acc: int
    num_sv: int
    flags: int
    sv_data: _containers.RepeatedCompositeFieldContainer[_measx_data_pb2.MeasxData]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., gps_tow: _Optional[int] = ..., glo_tow: _Optional[int] = ..., bds_tow: _Optional[int] = ..., qzss_tow: _Optional[int] = ..., gps_tow_acc: _Optional[int] = ..., glo_tow_acc: _Optional[int] = ..., bds_tow_acc: _Optional[int] = ..., qzss_tow_acc: _Optional[int] = ..., num_sv: _Optional[int] = ..., flags: _Optional[int] = ..., sv_data: _Optional[_Iterable[_Union[_measx_data_pb2.MeasxData, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Metadata(_message.Message):
    __slots__ = ("header", "ros2_header", "json_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    JSON_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    json_data: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., json_data: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_dispenser_msgs.msg import dispenser_request_item_pb2 as _dispenser_request_item_pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import behavior_pb2 as _behavior_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Delivery(_message.Message):
    __slots__ = ("task_id", "items", "pickup_place_name", "pickup_dispenser", "pickup_behavior", "dropoff_place_name", "dropoff_ingestor", "dropoff_behavior")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    PICKUP_PLACE_NAME_FIELD_NUMBER: _ClassVar[int]
    PICKUP_DISPENSER_FIELD_NUMBER: _ClassVar[int]
    PICKUP_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    DROPOFF_PLACE_NAME_FIELD_NUMBER: _ClassVar[int]
    DROPOFF_INGESTOR_FIELD_NUMBER: _ClassVar[int]
    DROPOFF_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    items: _containers.RepeatedCompositeFieldContainer[_dispenser_request_item_pb2.DispenserRequestItem]
    pickup_place_name: str
    pickup_dispenser: str
    pickup_behavior: _behavior_pb2.Behavior
    dropoff_place_name: str
    dropoff_ingestor: str
    dropoff_behavior: _behavior_pb2.Behavior
    def __init__(self, task_id: _Optional[str] = ..., items: _Optional[_Iterable[_Union[_dispenser_request_item_pb2.DispenserRequestItem, _Mapping]]] = ..., pickup_place_name: _Optional[str] = ..., pickup_dispenser: _Optional[str] = ..., pickup_behavior: _Optional[_Union[_behavior_pb2.Behavior, _Mapping]] = ..., dropoff_place_name: _Optional[str] = ..., dropoff_ingestor: _Optional[str] = ..., dropoff_behavior: _Optional[_Union[_behavior_pb2.Behavior, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceEventInfo(_message.Message):
    __slots__ = ("event_type", "stamp", "client_gid", "sequence_number")
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    CLIENT_GID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    event_type: int
    stamp: _time_pb2.Time
    client_gid: _containers.RepeatedScalarFieldContainer[int]
    sequence_number: int
    def __init__(self, event_type: _Optional[int] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., client_gid: _Optional[_Iterable[int]] = ..., sequence_number: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import service_details_pb2 as _service_details_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntrospectServicesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IntrospectServicesResponse(_message.Message):
    __slots__ = ("service_details",)
    SERVICE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    service_details: _containers.RepeatedCompositeFieldContainer[_service_details_pb2.ServiceDetails]
    def __init__(self, service_details: _Optional[_Iterable[_Union[_service_details_pb2.ServiceDetails, _Mapping]]] = ...) -> None: ...
